ListenerNotifier

Trait ListenerNotifier 

pub trait ListenerNotifier {
    // Required method
    fn new_incoming_connections(&mut self, num_ready: usize);
}
A notifier used to tell Bindings about new pending connections for a single socket.

Required Methods

fn new_incoming_connections(&mut self, num_ready: usize)

When the ready queue length has changed, signal to the Bindings.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors