pub trait ListenerNotifier {
// Required method
fn new_incoming_connections(&mut self, num_ready: usize);
}Expand description
A notifier used to tell Bindings about new pending connections for a single socket.
Required Methods
Sourcefn new_incoming_connections(&mut self, num_ready: usize)
fn new_incoming_connections(&mut self, num_ready: usize)
When the ready queue length has changed, signal to the Bindings.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".